@@ -7,18 +7,12 @@ def fun_args(subparsers, default_limit):
         description="Interactively search for tracks and albums.",
         help="interactive mode",
     )
-    interactive.add_argument(
-        "-a",
-        "--albums-only",
-        action="store_true",
-        help="enable albums-only search",
-    )
     interactive.add_argument(
         "-l",
         "--limit",
         metavar="int",
         default=default_limit,
-        help="limit of search results by type (default: 10)",
+        help="limit of search results (default: 20)",
     )
     return interactive
 
@@ -49,7 +43,7 @@ def lucky_args(subparsers):
 def dl_args(subparsers):
     download = subparsers.add_parser(
         "dl",
-        description="Download by album/track/artist/label/playlist URL.",
+        description="Download by album/track/artist/label/playlist/last.fm-playlist URL.",
         help="input mode",
     )
     download.add_argument(
@@ -82,10 +76,15 @@ def add_common_arg(custom_parser, default_folder, default_quality):
             "[320, LOSSLESS, 24B <96KHZ, 24B >96KHZ] (default: 6)"
         ),
     )
+    custom_parser.add_argument(
+        "--albums-only",
+        action="store_true",
+        help=("don't download singles, EPs and VA releases"),
+    )
 
 
 def qobuz_dl_args(
-    default_quality=6, default_limit=10, default_folder="Qobuz Downloads"
+    default_quality=6, default_limit=20, default_folder="Qobuz Downloads"
 ):
     parser = argparse.ArgumentParser(
         prog="qobuz-dl",
