@@ -57,8 +57,33 @@ def get_format(client, item_dict, quality, is_track_id=False):
         return "Unknown"
 
 
+def get_title(item_dict):
+    try:
+        album_title = (
+            ("{} ({})".format(item_dict["title"], item_dict["version"]))
+            if item_dict["version"]
+            and item_dict["version"].lower() not in item_dict["title"].lower()
+            else item_dict["title"]
+        )
+    except KeyError:
+        album_title = item_dict["title"]
+    try:
+        final_title = (
+            (album_title + " (Explicit)")
+            if item_dict["parental_warning"] and "explicit" not in album_title.lower()
+            else album_title
+        )
+    except KeyError:
+        final_title = album_title
+    return final_title
+
+
 def get_extra(i, dirn, extra="cover.jpg"):
-    tqdm_download(i, os.path.join(dirn, extra), "Downloading " + extra.split(".")[0])
+    tqdm_download(
+        i.replace("_600.", "_org."),
+        os.path.join(dirn, extra),
+        "Downloading " + extra.split(".")[0],
+    )
 
 
 # Download and tag a file
@@ -128,7 +153,9 @@ def download_and_tag(
         os.remove(filename)
 
 
-def download_id_by_type(client, item_id, path, quality, album=False, embed_art=False):
+def download_id_by_type(
+    client, item_id, path, quality, album=False, embed_art=False, albums_only=False
+):
     """
     Download and get metadata by ID and type (album or track)
 
@@ -136,20 +163,23 @@ def download_id_by_type(client, item_id, path, quality, album=False, embed_art=F
     :param int item_id: Qobuz item id
     :param str path: The root directory where the item will be downloaded
     :param int quality: Audio quality (5, 6, 7, 27)
-    :param bool album
+    :param bool album: album type or not
+    :param embed_art album: Embed cover art into files
+    :param bool albums_only: Ignore Singles, EPs and VA releases
     """
     count = 0
 
     if album:
         meta = client.get_album_meta(item_id)
-        try:
-            album_title = (
-                ("{} ({})".format(meta["title"], meta["version"]))
-                if meta["version"]
-                else meta["title"]
-            )
-        except KeyError:
-            album_title = meta["title"]
+
+        if albums_only and (
+            meta.get("release_type") != "album"
+            or meta.get("artist").get("name") == "Various Artists"
+        ):
+            print("Ignoring Single/EP/VA: " + meta.get("title", ""))
+            return
+
+        album_title = get_title(meta)
         print("\nDownloading: {}\n".format(album_title))
         dirT = (
             meta["artist"]["name"],
@@ -191,14 +221,7 @@ def download_id_by_type(client, item_id, path, quality, album=False, embed_art=F
 
         if "sample" not in parse and parse["sampling_rate"]:
             meta = client.get_track_meta(item_id)
-            try:
-                track_title = (
-                    ("{} ({})".format(meta["title"], meta["version"]))
-                    if meta["version"]
-                    else meta["title"]
-                )
-            except KeyError:
-                track_title = meta["title"]
+            track_title = get_title(meta)
             print("\nDownloading: {}\n".format(track_title))
             dirT = (
                 meta["album"]["artist"]["name"],
